==> tomee-project-7.0.1-source-release.zip: tomee-project-7.0.1/tomee/tomee-catalina/src/main/java/org/apache/tomee/catalina/TomEEContainerListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomee.catalina;

import org.apache.catalina.ContainerEvent;
import org.apache.catalina.ContainerListener;
import org.apache.catalina.core.StandardContext;


public class TomEEContainerListener implements ContainerListener {
    private static final ThreadLocal<StandardContext> context = new ThreadLocal<StandardContext>();

    @Override
    public void containerEvent(final ContainerEvent event) {
        if ("beforeContextInitialized".equals(event.getType())) {
            context.set((StandardContext) event.getContainer());
        } else if ("afterContextInitialized".equals(event.getType())) {
            context.remove();
        }
    }

    public static StandardContext get() {
        return context.get();
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/tomee/tomee-catalina/src/main/java/org/apache/tomee/catalina/TomEEContainerListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomee.catalina;

import org.apache.catalina.ContainerEvent;
import org.apache.catalina.ContainerListener;
import org.apache.catalina.core.StandardContext;


public class TomEEContainerListener implements ContainerListener {
    private static final ThreadLocal<StandardContext> CONTEXT = new ThreadLocal<StandardContext>();

    @Override
    public void containerEvent(final ContainerEvent event) {
        if ("beforeContextInitialized".equals(event.getType())) {
            CONTEXT.set((StandardContext) event.getContainer());
        } else if ("afterContextInitialized".equals(event.getType())) {
            CONTEXT.remove();
        }
    }

    public static StandardContext get() {
        return CONTEXT.get();
    }
}
